@@ -44,6 +44,7 @@
 #include <QTimer>
 #include <QStandardPaths>
 #include <QRandomGenerator>
+#include <QRegExp>
 
 #include <memory>
 
@@ -960,3 +961,5 @@ QStack< Move > Manager::moveHistory() const {
 	Q_D(const GameManager);
 	return d->moveHistory;
 }
+
+#include "moc_gamemanager.cpp"
